@@ -1,7 +1,7 @@
 import datetime
 import requests
 
-def main() -> None:
+def prices():
     exchange_prices = []
     currency_code = ['USD','NOK','EUR']
     for currency in currency_code:
@@ -14,7 +14,4 @@ def main() -> None:
     usdeur = exchange_prices[2]/exchange_prices[0]
     
     todays_prices = [date,usdnok,usdeur]
-    print(todays_prices)
-    
-if __name__ == "__main__":
-    main()
\ No newline at end of file
+    print(todays_prices)
\ No newline at end of file
